@@ -6,7 +6,7 @@ class media(object):
 	def __init__(self) -> int:
 		...
 
-	async def getThumbnail(self , image_bytes : bytes) -> bytes:
+	async def getImageThumbnail(self , image_bytes : bytes) -> bytes:
 		im = Image.open(BytesIO(image_bytes))
 		[width , height] = im.size
 		if height > width:
@@ -14,7 +14,7 @@ class media(object):
 			new_width  = round(new_height * width / height)
 		else:
 			new_width : int = 40
-			new_height = round(new_width * height / width)
+			new_height : int = round(new_width * height / width)
 			im = im.resize((new_width , new_height), Image.ANTIALIAS)
 			changed_image : bytes = BytesIO()
 			im.save(changed_image , format='PNG')
